.. :changelog:

History
=======


0.6.0b3 (2016-11-24)
=======
* Attempt fix for long running tvdb bug


0.6.0b1 (2016-05-15)
--------------------
* Fix cache file bug
* Improve locking


0.6.0b0 (2016-05-13)
--------------------
* Small debug output reduction
* Not running warning


0.6.0a0 (2016-05-13)
--------------------
* Change cli
* Change check/check_all interfaces (Use check_all like check before)
* Make StartStopable


0.5.4a0 (2016-05-05)
--------------------
* First release
